@@ -233,7 +233,7 @@ class Sequential():
             for i in range(len(self.train_layers)):
                 if i+1 == len(self.train_layers):
                     self.prediction = np.around(self.train_layers[i].forward())
-                    return np.around(self.train_layers[i].forward())
+                    return self.train_layers[i].forward()
                     break
                 self.train_layers[i+1].inputs = self.train_layers[i].forward()
             
@@ -378,7 +378,7 @@ class Sequential():
                                 X1, X2 = np.meshgrid(np.arange(start = X_set[:, 0].min() - 1, stop = X_set[:, 0].max() + 1, step = 0.01),
                                                      np.arange(start = X_set[:, 1].min() - 1, stop = X_set[:, 1].max() + 1, step = 0.01))
                                 axs2.contourf(X1, X2, self.predict(np.array([X1.ravel(), X2.ravel()]).T).reshape(X1.shape),
-                                             alpha = 0.2, cmap = "coolwarm")
+                                             alpha = 0.3, cmap = "coolwarm")
                                 
                             axs2.scatter(self.train_inputs[:,0], self.train_inputs[:,1], c=self.train_outputs[:,:], cmap="coolwarm", alpha=1)
                             
@@ -431,7 +431,7 @@ class Sequential():
                                 X1, X2 = np.meshgrid(np.arange(start = X_set[:, 0].min() - 1, stop = X_set[:, 0].max() + 1, step = 0.01),
                                                      np.arange(start = X_set[:, 1].min() - 1, stop = X_set[:, 1].max() + 1, step = 0.01))
                                 axs2.contourf(X1, X2, self.predict(np.array([X1.ravel(), X2.ravel()]).T).reshape(X1.shape),
-                                             alpha = 0.2, cmap = "coolwarm")
+                                             alpha = 0.3, cmap = "coolwarm")
                             
                             axs2.scatter(self.train_inputs[:,0], self.train_inputs[:,1], c=self.train_outputs[:,:], cmap="coolwarm", alpha=1)
                             
